==> wormux_0.7.4.orig.tar.gz: wormux-0.7.4/src/weapon/all.h <==
/******************************************************************************
 *  Wormux, a free clone of the game Worms from Team17.
 *  Copyright (C) 2001-2004 Lawrence Azzoug.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Include file to include all weapons in one shot ;-)
 *****************************************************************************/

#ifndef ALL_WEAPONS_H
#define ALL_WEAPONS_H

#include "airhammer.h"
#include "air_attack.h"
#include "auto_bazooka.h"
#include "baseball.h"
#include "bazooka.h"
#include "bounce_ball.h"
#include "cluster_bomb.h"
#include "dynamite.h"
#include "grenade.h"
#include "gun.h"
#include "gnu.h"
#include "holly_grenade.h"
#include "jetpack.h"
#include "lowgrav.h"
#include "mine.h"
#include "ninja_rope.h"
#include "parachute.h"
#include "skip_turn.h"
#include "suicide.h"
#include "supertux.h"
#include "teleportation.h"
#include "uzi.h"

#endif

==> wormux_0.7.9.orig.tar.gz: wormux-0.7.9/src/weapon/all.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2004 Lawrence Azzoug.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Include file to include all weapons in one shot ;-)
 *****************************************************************************/

#ifndef ALL_WEAPONS_H
#define ALL_WEAPONS_H

#include "airhammer.h"
#include "air_attack.h"
#include "anvil.h"
#include "auto_bazooka.h"
#include "baseball.h"
#include "bazooka.h"
#include "blowtorch.h"
#include "bounce_ball.h"
#include "cluster_bomb.h"
#include "construct.h"
#include "dynamite.h"
#include "gnu.h"
#include "grenade.h"
#include "gun.h"
#include "disco_grenade.h"
#include "jetpack.h"
#include "lowgrav.h"
#include "mine.h"
#include "ninja_rope.h"
#include "parachute.h"
#include "polecat.h"
#include "riot_bomb.h"
#include "shotgun.h"
#include "skip_turn.h"
#include "snipe_rifle.h"
#include "submachine_gun.h"
#include "suicide.h"
#include "supertux.h"
#include "teleportation.h"
#include "syringe.h"

#endif
